==> mathmoon-0.0.1.tar.bz2: mathmoon-0.0.1/src/button.h <==
// A mathematical game
// Copyright (C) 2004 by Christian von Schultz <schultz@linux.nu>

// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#ifndef BUTTON_H
#define BUTTON_H

#if defined(__WXMSW__)
#define wxUSE_OWNER_DRAWN 1
#endif

#include <wx/wx.h>

#include <wx/button.h>

#include <config.h>
#include "checksetup.h"

// This class extends the standard wxButton class with help text
// support (help text is shown in the statusbar).

#ifndef MY_EXPORT
#define MY_EXPORT WXDLLEXPORT
#endif

class MY_EXPORT Button: public wxButton
{
public:
  Button(wxWindow* parent,
	 wxWindowID id,
	 const wxString& label,
	 const wxPoint& pos = wxDefaultPosition,
	 const wxSize& size = wxDefaultSize,
	 long style = 0):
    wxButton(parent, id, label, pos, size, style) {}

  virtual ~Button() throw();

protected:
  DECLARE_EVENT_TABLE();

  void OnMouseEnter(wxMouseEvent &ev) throw();
  void OnMouseLeave(wxMouseEvent &ev) throw();
};

#endif // BUTTON_H

// 
// Local Variables:
// mode: c++
// End:

==> mathmoon-0.1.0.tar.bz2: mathmoon-0.1.0/src/button.h <==
// A mathematical game
// Copyright (C) 2004 by Christian von Schultz <schultz@linux.nu>

// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#ifndef BUTTON_H
#define BUTTON_H

#if defined(__WXMSW__)
#define wxUSE_OWNER_DRAWN 1
#endif

#include <wx/wx.h>

#include <wx/button.h>

#include <config.h>
#include "checksetup.h"

// This class extends the standard wxButton class with help text
// support (help text is shown in the statusbar).

class EXPORT Button: public wxButton
{
public:
  Button(wxWindow* parent,
	 wxWindowID id,
	 const wxString& label,
	 const wxPoint& pos = wxDefaultPosition,
	 const wxSize& size = wxDefaultSize,
	 long style = 0):
    wxButton(parent, id, label, pos, size, style) {}

  virtual ~Button() throw();

protected:
  DECLARE_EVENT_TABLE();

  void OnMouseEnter(wxMouseEvent &ev) throw();
  void OnMouseLeave(wxMouseEvent &ev) throw();
};

#endif // BUTTON_H

// 
// Local Variables:
// mode: c++
// End:
